@@ -2,7 +2,7 @@ package DashProfiler::Import;
 
 use strict;
 
-our $VERSION = sprintf("1.%06d", q$Revision: 31 $ =~ /(\d+)/o);
+our $VERSION = sprintf("1.%06d", q$Revision: 41 $ =~ /(\d+)/o);
 
 use base qw(Exporter);
 
@@ -113,3 +113,19 @@ sub import {
 }
 
 1;
+
+=head1 AUTHOR
+
+DashProfiler by Tim Bunce, L<http://www.tim.bunce.name> and
+L<http://blog.timbunce.org>
+
+=head1 COPYRIGHT
+        
+The DashProfiler distribution is Copyright (c) 2007-2008 Tim Bunce. Ireland.
+All rights reserved.
+
+You may distribute under the terms of either the GNU General Public
+License or the Artistic License, as specified in the Perl README file.
+
+=cut
+
